==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkSphereRepresentation.java <==
// java wrapper for vtkSphereRepresentation object
//

package vtk;
import vtk.*;

public class vtkSphereRepresentation extends vtkWidgetRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRepresentation_2(int id0);
  public void SetRepresentation(int id0)
    { SetRepresentation_2(id0); }

  private native int GetRepresentationMinValue_3();
  public int GetRepresentationMinValue()
    { return GetRepresentationMinValue_3(); }

  private native int GetRepresentationMaxValue_4();
  public int GetRepresentationMaxValue()
    { return GetRepresentationMaxValue_4(); }

  private native int GetRepresentation_5();
  public int GetRepresentation()
    { return GetRepresentation_5(); }

  private native void SetRepresentationToOff_6();
  public void SetRepresentationToOff()
    { SetRepresentationToOff_6(); }

  private native void SetRepresentationToWireframe_7();
  public void SetRepresentationToWireframe()
    { SetRepresentationToWireframe_7(); }

  private native void SetRepresentationToSurface_8();
  public void SetRepresentationToSurface()
    { SetRepresentationToSurface_8(); }

  private native void SetThetaResolution_9(int id0);
  public void SetThetaResolution(int id0)
    { SetThetaResolution_9(id0); }

  private native int GetThetaResolution_10();
  public int GetThetaResolution()
    { return GetThetaResolution_10(); }

  private native void SetPhiResolution_11(int id0);
  public void SetPhiResolution(int id0)
    { SetPhiResolution_11(id0); }

  private native int GetPhiResolution_12();
  public int GetPhiResolution()
    { return GetPhiResolution_12(); }

  private native void SetCenter_13(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_13(id0); }

  private native void SetCenter_14(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_14(id0,id1,id2); }

  private native double[] GetCenter_15();
  public double[] GetCenter()
    { return GetCenter_15(); }

  private native void GetCenter_16(double id0[]);
  public void GetCenter(double id0[])
    { GetCenter_16(id0); }

  private native void SetRadius_17(double id0);
  public void SetRadius(double id0)
    { SetRadius_17(id0); }

  private native double GetRadius_18();
  public double GetRadius()
    { return GetRadius_18(); }

  private native void SetHandleVisibility_19(int id0);
  public void SetHandleVisibility(int id0)
    { SetHandleVisibility_19(id0); }

  private native int GetHandleVisibility_20();
  public int GetHandleVisibility()
    { return GetHandleVisibility_20(); }

  private native void HandleVisibilityOn_21();
  public void HandleVisibilityOn()
    { HandleVisibilityOn_21(); }

  private native void HandleVisibilityOff_22();
  public void HandleVisibilityOff()
    { HandleVisibilityOff_22(); }

  private native void SetHandlePosition_23(double id0[]);
  public void SetHandlePosition(double id0[])
    { SetHandlePosition_23(id0); }

  private native void SetHandlePosition_24(double id0,double id1,double id2);
  public void SetHandlePosition(double id0,double id1,double id2)
    { SetHandlePosition_24(id0,id1,id2); }

  private native double[] GetHandlePosition_25();
  public double[] GetHandlePosition()
    { return GetHandlePosition_25(); }

  private native void SetHandleDirection_26(double id0[]);
  public void SetHandleDirection(double id0[])
    { SetHandleDirection_26(id0); }

  private native void SetHandleDirection_27(double id0,double id1,double id2);
  public void SetHandleDirection(double id0,double id1,double id2)
    { SetHandleDirection_27(id0,id1,id2); }

  private native double[] GetHandleDirection_28();
  public double[] GetHandleDirection()
    { return GetHandleDirection_28(); }

  private native void SetHandleText_29(int id0);
  public void SetHandleText(int id0)
    { SetHandleText_29(id0); }

  private native int GetHandleText_30();
  public int GetHandleText()
    { return GetHandleText_30(); }

  private native void HandleTextOn_31();
  public void HandleTextOn()
    { HandleTextOn_31(); }

  private native void HandleTextOff_32();
  public void HandleTextOff()
    { HandleTextOff_32(); }

  private native void SetRadialLine_33(int id0);
  public void SetRadialLine(int id0)
    { SetRadialLine_33(id0); }

  private native int GetRadialLine_34();
  public int GetRadialLine()
    { return GetRadialLine_34(); }

  private native void RadialLineOn_35();
  public void RadialLineOn()
    { RadialLineOn_35(); }

  private native void RadialLineOff_36();
  public void RadialLineOff()
    { RadialLineOff_36(); }

  private native void SetCenterCursor_37(boolean id0);
  public void SetCenterCursor(boolean id0)
    { SetCenterCursor_37(id0); }

  private native boolean GetCenterCursor_38();
  public boolean GetCenterCursor()
    { return GetCenterCursor_38(); }

  private native void CenterCursorOn_39();
  public void CenterCursorOn()
    { CenterCursorOn_39(); }

  private native void CenterCursorOff_40();
  public void CenterCursorOff()
    { CenterCursorOff_40(); }

  private native void GetPolyData_41(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_41(id0); }

  private native void GetSphere_42(vtkSphere id0);
  public void GetSphere(vtkSphere id0)
    { GetSphere_42(id0); }

  private native long GetSphereProperty_43();
  public vtkProperty GetSphereProperty() {
    long temp = GetSphereProperty_43();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedSphereProperty_44();
  public vtkProperty GetSelectedSphereProperty() {
    long temp = GetSelectedSphereProperty_44();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetHandleProperty_45();
  public vtkProperty GetHandleProperty() {
    long temp = GetHandleProperty_45();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedHandleProperty_46();
  public vtkProperty GetSelectedHandleProperty() {
    long temp = GetSelectedHandleProperty_46();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetHandleTextProperty_47();
  public vtkTextProperty GetHandleTextProperty() {
    long temp = GetHandleTextProperty_47();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRadialLineProperty_48();
  public vtkProperty GetRadialLineProperty() {
    long temp = GetRadialLineProperty_48();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInteractionState_49(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_49(id0); }

  private native void PlaceWidget_50(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_50(id0); }

  private native void PlaceWidget_51(double id0[],double id1[]);
  public void PlaceWidget(double id0[],double id1[])
    { PlaceWidget_51(id0,id1); }

  private native void BuildRepresentation_52();
  public void BuildRepresentation()
    { BuildRepresentation_52(); }

  private native int ComputeInteractionState_53(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_53(id0,id1,id2); }

  private native void StartWidgetInteraction_54(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_54(id0); }

  private native void WidgetInteraction_55(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_55(id0); }

  private native void ReleaseGraphicsResources_56(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_56(id0); }

  private native int RenderOpaqueGeometry_57(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_57(id0); }

  private native int RenderTranslucentPolygonalGeometry_58(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_58(id0); }

  private native int RenderOverlay_59(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_59(id0); }

  private native int HasTranslucentPolygonalGeometry_60();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_60(); }

  public vtkSphereRepresentation() { super(); }

  public vtkSphereRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-15-armv7h.pkg.tar.xz: vtk/vtkSphereRepresentation.java <==
// java wrapper for vtkSphereRepresentation object
//

package vtk;
import vtk.*;

public class vtkSphereRepresentation extends vtkWidgetRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRepresentation_2(int id0);
  public void SetRepresentation(int id0)
    { SetRepresentation_2(id0); }

  private native int GetRepresentationMinValue_3();
  public int GetRepresentationMinValue()
    { return GetRepresentationMinValue_3(); }

  private native int GetRepresentationMaxValue_4();
  public int GetRepresentationMaxValue()
    { return GetRepresentationMaxValue_4(); }

  private native int GetRepresentation_5();
  public int GetRepresentation()
    { return GetRepresentation_5(); }

  private native void SetRepresentationToOff_6();
  public void SetRepresentationToOff()
    { SetRepresentationToOff_6(); }

  private native void SetRepresentationToWireframe_7();
  public void SetRepresentationToWireframe()
    { SetRepresentationToWireframe_7(); }

  private native void SetRepresentationToSurface_8();
  public void SetRepresentationToSurface()
    { SetRepresentationToSurface_8(); }

  private native void SetThetaResolution_9(int id0);
  public void SetThetaResolution(int id0)
    { SetThetaResolution_9(id0); }

  private native int GetThetaResolution_10();
  public int GetThetaResolution()
    { return GetThetaResolution_10(); }

  private native void SetPhiResolution_11(int id0);
  public void SetPhiResolution(int id0)
    { SetPhiResolution_11(id0); }

  private native int GetPhiResolution_12();
  public int GetPhiResolution()
    { return GetPhiResolution_12(); }

  private native void SetCenter_13(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_13(id0); }

  private native void SetCenter_14(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_14(id0,id1,id2); }

  private native double[] GetCenter_15();
  public double[] GetCenter()
    { return GetCenter_15(); }

  private native void GetCenter_16(double id0[]);
  public void GetCenter(double id0[])
    { GetCenter_16(id0); }

  private native void SetRadius_17(double id0);
  public void SetRadius(double id0)
    { SetRadius_17(id0); }

  private native double GetRadius_18();
  public double GetRadius()
    { return GetRadius_18(); }

  private native void SetHandleVisibility_19(int id0);
  public void SetHandleVisibility(int id0)
    { SetHandleVisibility_19(id0); }

  private native int GetHandleVisibility_20();
  public int GetHandleVisibility()
    { return GetHandleVisibility_20(); }

  private native void HandleVisibilityOn_21();
  public void HandleVisibilityOn()
    { HandleVisibilityOn_21(); }

  private native void HandleVisibilityOff_22();
  public void HandleVisibilityOff()
    { HandleVisibilityOff_22(); }

  private native void SetHandlePosition_23(double id0[]);
  public void SetHandlePosition(double id0[])
    { SetHandlePosition_23(id0); }

  private native void SetHandlePosition_24(double id0,double id1,double id2);
  public void SetHandlePosition(double id0,double id1,double id2)
    { SetHandlePosition_24(id0,id1,id2); }

  private native double[] GetHandlePosition_25();
  public double[] GetHandlePosition()
    { return GetHandlePosition_25(); }

  private native void SetHandleDirection_26(double id0[]);
  public void SetHandleDirection(double id0[])
    { SetHandleDirection_26(id0); }

  private native void SetHandleDirection_27(double id0,double id1,double id2);
  public void SetHandleDirection(double id0,double id1,double id2)
    { SetHandleDirection_27(id0,id1,id2); }

  private native double[] GetHandleDirection_28();
  public double[] GetHandleDirection()
    { return GetHandleDirection_28(); }

  private native void SetHandleText_29(int id0);
  public void SetHandleText(int id0)
    { SetHandleText_29(id0); }

  private native int GetHandleText_30();
  public int GetHandleText()
    { return GetHandleText_30(); }

  private native void HandleTextOn_31();
  public void HandleTextOn()
    { HandleTextOn_31(); }

  private native void HandleTextOff_32();
  public void HandleTextOff()
    { HandleTextOff_32(); }

  private native void SetRadialLine_33(int id0);
  public void SetRadialLine(int id0)
    { SetRadialLine_33(id0); }

  private native int GetRadialLine_34();
  public int GetRadialLine()
    { return GetRadialLine_34(); }

  private native void RadialLineOn_35();
  public void RadialLineOn()
    { RadialLineOn_35(); }

  private native void RadialLineOff_36();
  public void RadialLineOff()
    { RadialLineOff_36(); }

  private native void SetCenterCursor_37(boolean id0);
  public void SetCenterCursor(boolean id0)
    { SetCenterCursor_37(id0); }

  private native boolean GetCenterCursor_38();
  public boolean GetCenterCursor()
    { return GetCenterCursor_38(); }

  private native void CenterCursorOn_39();
  public void CenterCursorOn()
    { CenterCursorOn_39(); }

  private native void CenterCursorOff_40();
  public void CenterCursorOff()
    { CenterCursorOff_40(); }

  private native void GetPolyData_41(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_41(id0); }

  private native void GetSphere_42(vtkSphere id0);
  public void GetSphere(vtkSphere id0)
    { GetSphere_42(id0); }

  private native long GetSphereProperty_43();
  public vtkProperty GetSphereProperty() {
    long temp = GetSphereProperty_43();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedSphereProperty_44();
  public vtkProperty GetSelectedSphereProperty() {
    long temp = GetSelectedSphereProperty_44();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetHandleProperty_45();
  public vtkProperty GetHandleProperty() {
    long temp = GetHandleProperty_45();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedHandleProperty_46();
  public vtkProperty GetSelectedHandleProperty() {
    long temp = GetSelectedHandleProperty_46();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetHandleTextProperty_47();
  public vtkTextProperty GetHandleTextProperty() {
    long temp = GetHandleTextProperty_47();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRadialLineProperty_48();
  public vtkProperty GetRadialLineProperty() {
    long temp = GetRadialLineProperty_48();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInteractionState_49(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_49(id0); }

  private native void PlaceWidget_50(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_50(id0); }

  private native void PlaceWidget_51(double id0[],double id1[]);
  public void PlaceWidget(double id0[],double id1[])
    { PlaceWidget_51(id0,id1); }

  private native void BuildRepresentation_52();
  public void BuildRepresentation()
    { BuildRepresentation_52(); }

  private native int ComputeInteractionState_53(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_53(id0,id1,id2); }

  private native void StartWidgetInteraction_54(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_54(id0); }

  private native void WidgetInteraction_55(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_55(id0); }

  private native void ReleaseGraphicsResources_56(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_56(id0); }

  private native int RenderOpaqueGeometry_57(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_57(id0); }

  private native int RenderTranslucentPolygonalGeometry_58(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_58(id0); }

  private native int RenderOverlay_59(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_59(id0); }

  private native int HasTranslucentPolygonalGeometry_60();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_60(); }

  private native void RegisterPickers_61();
  public void RegisterPickers()
    { RegisterPickers_61(); }

  public vtkSphereRepresentation() { super(); }

  public vtkSphereRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
